# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ScaleBlockchainPlatformDetails(object):
    """
    Scale operation details for a blockchain platform. The scale operation payload has multiple options
    - Add one or more Ordering Service Node (addOsns)
    - Add one or more Peers (addPeers)
    - Add more replicas of CA, Console and Rest Proxy (addReplicas)
    - Add more storage to the platform (addStorage)
    - Modify the CPU allocation for Peer Nodes (modifyPeers)
    - Remove one or more replicas of CA, Console and Rest Proxy (removeReplicas)
    - Remove one or more Ordering Service Node (removeOsns)
    - Remove one or more Peers (removePeers).
    The scale operation payload must have at least one of the above options.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ScaleBlockchainPlatformDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param add_osns:
            The value to assign to the add_osns property of this ScaleBlockchainPlatformDetails.
        :type add_osns: list[oci.blockchain.models.CreateOsnDetails]

        :param add_replicas:
            The value to assign to the add_replicas property of this ScaleBlockchainPlatformDetails.
        :type add_replicas: oci.blockchain.models.ReplicaDetails

        :param add_peers:
            The value to assign to the add_peers property of this ScaleBlockchainPlatformDetails.
        :type add_peers: list[oci.blockchain.models.CreatePeerDetails]

        :param add_storage:
            The value to assign to the add_storage property of this ScaleBlockchainPlatformDetails.
        :type add_storage: oci.blockchain.models.ScaleStorageDetails

        :param modify_peers:
            The value to assign to the modify_peers property of this ScaleBlockchainPlatformDetails.
        :type modify_peers: list[oci.blockchain.models.ModifyPeerDetails]

        :param remove_replicas:
            The value to assign to the remove_replicas property of this ScaleBlockchainPlatformDetails.
        :type remove_replicas: oci.blockchain.models.ReplicaDetails

        :param remove_osns:
            The value to assign to the remove_osns property of this ScaleBlockchainPlatformDetails.
        :type remove_osns: list[str]

        :param remove_peers:
            The value to assign to the remove_peers property of this ScaleBlockchainPlatformDetails.
        :type remove_peers: list[str]

        """
        self.swagger_types = {
            'add_osns': 'list[CreateOsnDetails]',
            'add_replicas': 'ReplicaDetails',
            'add_peers': 'list[CreatePeerDetails]',
            'add_storage': 'ScaleStorageDetails',
            'modify_peers': 'list[ModifyPeerDetails]',
            'remove_replicas': 'ReplicaDetails',
            'remove_osns': 'list[str]',
            'remove_peers': 'list[str]'
        }

        self.attribute_map = {
            'add_osns': 'addOsns',
            'add_replicas': 'addReplicas',
            'add_peers': 'addPeers',
            'add_storage': 'addStorage',
            'modify_peers': 'modifyPeers',
            'remove_replicas': 'removeReplicas',
            'remove_osns': 'removeOsns',
            'remove_peers': 'removePeers'
        }

        self._add_osns = None
        self._add_replicas = None
        self._add_peers = None
        self._add_storage = None
        self._modify_peers = None
        self._remove_replicas = None
        self._remove_osns = None
        self._remove_peers = None

    @property
    def add_osns(self):
        """
        Gets the add_osns of this ScaleBlockchainPlatformDetails.
        new OSNs to add


        :return: The add_osns of this ScaleBlockchainPlatformDetails.
        :rtype: list[oci.blockchain.models.CreateOsnDetails]
        """
        return self._add_osns

    @add_osns.setter
    def add_osns(self, add_osns):
        """
        Sets the add_osns of this ScaleBlockchainPlatformDetails.
        new OSNs to add


        :param add_osns: The add_osns of this ScaleBlockchainPlatformDetails.
        :type: list[oci.blockchain.models.CreateOsnDetails]
        """
        self._add_osns = add_osns

    @property
    def add_replicas(self):
        """
        Gets the add_replicas of this ScaleBlockchainPlatformDetails.

        :return: The add_replicas of this ScaleBlockchainPlatformDetails.
        :rtype: oci.blockchain.models.ReplicaDetails
        """
        return self._add_replicas

    @add_replicas.setter
    def add_replicas(self, add_replicas):
        """
        Sets the add_replicas of this ScaleBlockchainPlatformDetails.

        :param add_replicas: The add_replicas of this ScaleBlockchainPlatformDetails.
        :type: oci.blockchain.models.ReplicaDetails
        """
        self._add_replicas = add_replicas

    @property
    def add_peers(self):
        """
        Gets the add_peers of this ScaleBlockchainPlatformDetails.
        new Peers to add


        :return: The add_peers of this ScaleBlockchainPlatformDetails.
        :rtype: list[oci.blockchain.models.CreatePeerDetails]
        """
        return self._add_peers

    @add_peers.setter
    def add_peers(self, add_peers):
        """
        Sets the add_peers of this ScaleBlockchainPlatformDetails.
        new Peers to add


        :param add_peers: The add_peers of this ScaleBlockchainPlatformDetails.
        :type: list[oci.blockchain.models.CreatePeerDetails]
        """
        self._add_peers = add_peers

    @property
    def add_storage(self):
        """
        Gets the add_storage of this ScaleBlockchainPlatformDetails.

        :return: The add_storage of this ScaleBlockchainPlatformDetails.
        :rtype: oci.blockchain.models.ScaleStorageDetails
        """
        return self._add_storage

    @add_storage.setter
    def add_storage(self, add_storage):
        """
        Sets the add_storage of this ScaleBlockchainPlatformDetails.

        :param add_storage: The add_storage of this ScaleBlockchainPlatformDetails.
        :type: oci.blockchain.models.ScaleStorageDetails
        """
        self._add_storage = add_storage

    @property
    def modify_peers(self):
        """
        Gets the modify_peers of this ScaleBlockchainPlatformDetails.
        modify ocpu allocation to existing Peers


        :return: The modify_peers of this ScaleBlockchainPlatformDetails.
        :rtype: list[oci.blockchain.models.ModifyPeerDetails]
        """
        return self._modify_peers

    @modify_peers.setter
    def modify_peers(self, modify_peers):
        """
        Sets the modify_peers of this ScaleBlockchainPlatformDetails.
        modify ocpu allocation to existing Peers


        :param modify_peers: The modify_peers of this ScaleBlockchainPlatformDetails.
        :type: list[oci.blockchain.models.ModifyPeerDetails]
        """
        self._modify_peers = modify_peers

    @property
    def remove_replicas(self):
        """
        Gets the remove_replicas of this ScaleBlockchainPlatformDetails.

        :return: The remove_replicas of this ScaleBlockchainPlatformDetails.
        :rtype: oci.blockchain.models.ReplicaDetails
        """
        return self._remove_replicas

    @remove_replicas.setter
    def remove_replicas(self, remove_replicas):
        """
        Sets the remove_replicas of this ScaleBlockchainPlatformDetails.

        :param remove_replicas: The remove_replicas of this ScaleBlockchainPlatformDetails.
        :type: oci.blockchain.models.ReplicaDetails
        """
        self._remove_replicas = remove_replicas

    @property
    def remove_osns(self):
        """
        Gets the remove_osns of this ScaleBlockchainPlatformDetails.
        OSN id list to remove


        :return: The remove_osns of this ScaleBlockchainPlatformDetails.
        :rtype: list[str]
        """
        return self._remove_osns

    @remove_osns.setter
    def remove_osns(self, remove_osns):
        """
        Sets the remove_osns of this ScaleBlockchainPlatformDetails.
        OSN id list to remove


        :param remove_osns: The remove_osns of this ScaleBlockchainPlatformDetails.
        :type: list[str]
        """
        self._remove_osns = remove_osns

    @property
    def remove_peers(self):
        """
        Gets the remove_peers of this ScaleBlockchainPlatformDetails.
        Peer id list to remove


        :return: The remove_peers of this ScaleBlockchainPlatformDetails.
        :rtype: list[str]
        """
        return self._remove_peers

    @remove_peers.setter
    def remove_peers(self, remove_peers):
        """
        Sets the remove_peers of this ScaleBlockchainPlatformDetails.
        Peer id list to remove


        :param remove_peers: The remove_peers of this ScaleBlockchainPlatformDetails.
        :type: list[str]
        """
        self._remove_peers = remove_peers

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApplicationSummary(object):
    """
    Summary of an application.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApplicationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ApplicationSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ApplicationSummary.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this ApplicationSummary.
        :type display_name: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ApplicationSummary.
        :type lifecycle_state: str

        :param subnet_ids:
            The value to assign to the subnet_ids property of this ApplicationSummary.
        :type subnet_ids: list[str]

        :param network_security_group_ids:
            The value to assign to the network_security_group_ids property of this ApplicationSummary.
        :type network_security_group_ids: list[str]

        :param trace_config:
            The value to assign to the trace_config property of this ApplicationSummary.
        :type trace_config: oci.functions.models.ApplicationTraceConfig

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ApplicationSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ApplicationSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param time_created:
            The value to assign to the time_created property of this ApplicationSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ApplicationSummary.
        :type time_updated: datetime

        :param image_policy_config:
            The value to assign to the image_policy_config property of this ApplicationSummary.
        :type image_policy_config: oci.functions.models.ImagePolicyConfig

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'lifecycle_state': 'str',
            'subnet_ids': 'list[str]',
            'network_security_group_ids': 'list[str]',
            'trace_config': 'ApplicationTraceConfig',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'image_policy_config': 'ImagePolicyConfig'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'lifecycle_state': 'lifecycleState',
            'subnet_ids': 'subnetIds',
            'network_security_group_ids': 'networkSecurityGroupIds',
            'trace_config': 'traceConfig',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'image_policy_config': 'imagePolicyConfig'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._lifecycle_state = None
        self._subnet_ids = None
        self._network_security_group_ids = None
        self._trace_config = None
        self._freeform_tags = None
        self._defined_tags = None
        self._time_created = None
        self._time_updated = None
        self._image_policy_config = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ApplicationSummary.
        The `OCID`__ of the application.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this ApplicationSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ApplicationSummary.
        The `OCID`__ of the application.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this ApplicationSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this ApplicationSummary.
        The OCID of the compartment that contains the application.


        :return: The compartment_id of this ApplicationSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ApplicationSummary.
        The OCID of the compartment that contains the application.


        :param compartment_id: The compartment_id of this ApplicationSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this ApplicationSummary.
        The display name of the application. The display name is unique within the compartment containing the application.


        :return: The display_name of this ApplicationSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ApplicationSummary.
        The display name of the application. The display name is unique within the compartment containing the application.


        :param display_name: The display_name of this ApplicationSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this ApplicationSummary.
        The current state of the application.


        :return: The lifecycle_state of this ApplicationSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ApplicationSummary.
        The current state of the application.


        :param lifecycle_state: The lifecycle_state of this ApplicationSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def subnet_ids(self):
        """
        Gets the subnet_ids of this ApplicationSummary.
        The `OCID`__s of the subnets in which to run functions in the application.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The subnet_ids of this ApplicationSummary.
        :rtype: list[str]
        """
        return self._subnet_ids

    @subnet_ids.setter
    def subnet_ids(self, subnet_ids):
        """
        Sets the subnet_ids of this ApplicationSummary.
        The `OCID`__s of the subnets in which to run functions in the application.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param subnet_ids: The subnet_ids of this ApplicationSummary.
        :type: list[str]
        """
        self._subnet_ids = subnet_ids

    @property
    def network_security_group_ids(self):
        """
        Gets the network_security_group_ids of this ApplicationSummary.
        The `OCID`__s of the Network Security Groups to add the application to.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The network_security_group_ids of this ApplicationSummary.
        :rtype: list[str]
        """
        return self._network_security_group_ids

    @network_security_group_ids.setter
    def network_security_group_ids(self, network_security_group_ids):
        """
        Sets the network_security_group_ids of this ApplicationSummary.
        The `OCID`__s of the Network Security Groups to add the application to.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param network_security_group_ids: The network_security_group_ids of this ApplicationSummary.
        :type: list[str]
        """
        self._network_security_group_ids = network_security_group_ids

    @property
    def trace_config(self):
        """
        Gets the trace_config of this ApplicationSummary.

        :return: The trace_config of this ApplicationSummary.
        :rtype: oci.functions.models.ApplicationTraceConfig
        """
        return self._trace_config

    @trace_config.setter
    def trace_config(self, trace_config):
        """
        Sets the trace_config of this ApplicationSummary.

        :param trace_config: The trace_config of this ApplicationSummary.
        :type: oci.functions.models.ApplicationTraceConfig
        """
        self._trace_config = trace_config

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ApplicationSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this ApplicationSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ApplicationSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this ApplicationSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ApplicationSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this ApplicationSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ApplicationSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this ApplicationSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def time_created(self):
        """
        Gets the time_created of this ApplicationSummary.
        The time the application was created, expressed in `RFC 3339`__
        timestamp format.

        Example: `2018-09-12T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this ApplicationSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ApplicationSummary.
        The time the application was created, expressed in `RFC 3339`__
        timestamp format.

        Example: `2018-09-12T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this ApplicationSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this ApplicationSummary.
        The time the application was updated, expressed in `RFC 3339`__
        timestamp format.
        Example: `2018-09-12T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this ApplicationSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ApplicationSummary.
        The time the application was updated, expressed in `RFC 3339`__
        timestamp format.
        Example: `2018-09-12T22:47:12.613Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this ApplicationSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def image_policy_config(self):
        """
        Gets the image_policy_config of this ApplicationSummary.

        :return: The image_policy_config of this ApplicationSummary.
        :rtype: oci.functions.models.ImagePolicyConfig
        """
        return self._image_policy_config

    @image_policy_config.setter
    def image_policy_config(self, image_policy_config):
        """
        Sets the image_policy_config of this ApplicationSummary.

        :param image_policy_config: The image_policy_config of this ApplicationSummary.
        :type: oci.functions.models.ImagePolicyConfig
        """
        self._image_policy_config = image_policy_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .scaling_policy import ScalingPolicy
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FixedSizeScalingPolicy(ScalingPolicy):
    """
    The fixed size scaling policy.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FixedSizeScalingPolicy object with values from keyword arguments. The default value of the :py:attr:`~oci.data_science.models.FixedSizeScalingPolicy.policy_type` attribute
        of this class is ``FIXED_SIZE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param policy_type:
            The value to assign to the policy_type property of this FixedSizeScalingPolicy.
            Allowed values for this property are: "FIXED_SIZE"
        :type policy_type: str

        :param instance_count:
            The value to assign to the instance_count property of this FixedSizeScalingPolicy.
        :type instance_count: int

        """
        self.swagger_types = {
            'policy_type': 'str',
            'instance_count': 'int'
        }

        self.attribute_map = {
            'policy_type': 'policyType',
            'instance_count': 'instanceCount'
        }

        self._policy_type = None
        self._instance_count = None
        self._policy_type = 'FIXED_SIZE'

    @property
    def instance_count(self):
        """
        **[Required]** Gets the instance_count of this FixedSizeScalingPolicy.
        The number of instances for the model deployment.


        :return: The instance_count of this FixedSizeScalingPolicy.
        :rtype: int
        """
        return self._instance_count

    @instance_count.setter
    def instance_count(self, instance_count):
        """
        Sets the instance_count of this FixedSizeScalingPolicy.
        The number of instances for the model deployment.


        :param instance_count: The instance_count of this FixedSizeScalingPolicy.
        :type: int
        """
        self._instance_count = instance_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsEntitySummaryReport(object):
    """
    Log-Analytics entity counts summary.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsEntitySummaryReport object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param active_entities_count:
            The value to assign to the active_entities_count property of this LogAnalyticsEntitySummaryReport.
        :type active_entities_count: int

        :param entities_with_has_logs_collected_count:
            The value to assign to the entities_with_has_logs_collected_count property of this LogAnalyticsEntitySummaryReport.
        :type entities_with_has_logs_collected_count: int

        :param entities_with_management_agent_count:
            The value to assign to the entities_with_management_agent_count property of this LogAnalyticsEntitySummaryReport.
        :type entities_with_management_agent_count: int

        :param compartment_id:
            The value to assign to the compartment_id property of this LogAnalyticsEntitySummaryReport.
        :type compartment_id: str

        """
        self.swagger_types = {
            'active_entities_count': 'int',
            'entities_with_has_logs_collected_count': 'int',
            'entities_with_management_agent_count': 'int',
            'compartment_id': 'str'
        }

        self.attribute_map = {
            'active_entities_count': 'activeEntitiesCount',
            'entities_with_has_logs_collected_count': 'entitiesWithHasLogsCollectedCount',
            'entities_with_management_agent_count': 'entitiesWithManagementAgentCount',
            'compartment_id': 'compartmentId'
        }

        self._active_entities_count = None
        self._entities_with_has_logs_collected_count = None
        self._entities_with_management_agent_count = None
        self._compartment_id = None

    @property
    def active_entities_count(self):
        """
        **[Required]** Gets the active_entities_count of this LogAnalyticsEntitySummaryReport.
        Total number of ACTIVE entities


        :return: The active_entities_count of this LogAnalyticsEntitySummaryReport.
        :rtype: int
        """
        return self._active_entities_count

    @active_entities_count.setter
    def active_entities_count(self, active_entities_count):
        """
        Sets the active_entities_count of this LogAnalyticsEntitySummaryReport.
        Total number of ACTIVE entities


        :param active_entities_count: The active_entities_count of this LogAnalyticsEntitySummaryReport.
        :type: int
        """
        self._active_entities_count = active_entities_count

    @property
    def entities_with_has_logs_collected_count(self):
        """
        **[Required]** Gets the entities_with_has_logs_collected_count of this LogAnalyticsEntitySummaryReport.
        Entities with log collection enabled


        :return: The entities_with_has_logs_collected_count of this LogAnalyticsEntitySummaryReport.
        :rtype: int
        """
        return self._entities_with_has_logs_collected_count

    @entities_with_has_logs_collected_count.setter
    def entities_with_has_logs_collected_count(self, entities_with_has_logs_collected_count):
        """
        Sets the entities_with_has_logs_collected_count of this LogAnalyticsEntitySummaryReport.
        Entities with log collection enabled


        :param entities_with_has_logs_collected_count: The entities_with_has_logs_collected_count of this LogAnalyticsEntitySummaryReport.
        :type: int
        """
        self._entities_with_has_logs_collected_count = entities_with_has_logs_collected_count

    @property
    def entities_with_management_agent_count(self):
        """
        **[Required]** Gets the entities_with_management_agent_count of this LogAnalyticsEntitySummaryReport.
        Entities with management agent


        :return: The entities_with_management_agent_count of this LogAnalyticsEntitySummaryReport.
        :rtype: int
        """
        return self._entities_with_management_agent_count

    @entities_with_management_agent_count.setter
    def entities_with_management_agent_count(self, entities_with_management_agent_count):
        """
        Sets the entities_with_management_agent_count of this LogAnalyticsEntitySummaryReport.
        Entities with management agent


        :param entities_with_management_agent_count: The entities_with_management_agent_count of this LogAnalyticsEntitySummaryReport.
        :type: int
        """
        self._entities_with_management_agent_count = entities_with_management_agent_count

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this LogAnalyticsEntitySummaryReport.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this LogAnalyticsEntitySummaryReport.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this LogAnalyticsEntitySummaryReport.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this LogAnalyticsEntitySummaryReport.
        :type: str
        """
        self._compartment_id = compartment_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StrategyParameter(object):
    """
    The metadata associated with the strategy parameter.
    """

    #: A constant which can be used with the type property of a StrategyParameter.
    #: This constant has a value of "STRING"
    TYPE_STRING = "STRING"

    #: A constant which can be used with the type property of a StrategyParameter.
    #: This constant has a value of "BOOLEAN"
    TYPE_BOOLEAN = "BOOLEAN"

    #: A constant which can be used with the type property of a StrategyParameter.
    #: This constant has a value of "NUMBER"
    TYPE_NUMBER = "NUMBER"

    #: A constant which can be used with the type property of a StrategyParameter.
    #: This constant has a value of "DATETIME"
    TYPE_DATETIME = "DATETIME"

    def __init__(self, **kwargs):
        """
        Initializes a new StrategyParameter object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this StrategyParameter.
        :type name: str

        :param type:
            The value to assign to the type property of this StrategyParameter.
            Allowed values for this property are: "STRING", "BOOLEAN", "NUMBER", "DATETIME", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param description:
            The value to assign to the description property of this StrategyParameter.
        :type description: str

        :param is_required:
            The value to assign to the is_required property of this StrategyParameter.
        :type is_required: bool

        :param default_value:
            The value to assign to the default_value property of this StrategyParameter.
        :type default_value: object

        :param possible_values:
            The value to assign to the possible_values property of this StrategyParameter.
        :type possible_values: list[object]

        """
        self.swagger_types = {
            'name': 'str',
            'type': 'str',
            'description': 'str',
            'is_required': 'bool',
            'default_value': 'object',
            'possible_values': 'list[object]'
        }

        self.attribute_map = {
            'name': 'name',
            'type': 'type',
            'description': 'description',
            'is_required': 'isRequired',
            'default_value': 'defaultValue',
            'possible_values': 'possibleValues'
        }

        self._name = None
        self._type = None
        self._description = None
        self._is_required = None
        self._default_value = None
        self._possible_values = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this StrategyParameter.
        The name of the strategy parameter.


        :return: The name of this StrategyParameter.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this StrategyParameter.
        The name of the strategy parameter.


        :param name: The name of this StrategyParameter.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        **[Required]** Gets the type of this StrategyParameter.
        The type of strategy parameter.

        Allowed values for this property are: "STRING", "BOOLEAN", "NUMBER", "DATETIME", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this StrategyParameter.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this StrategyParameter.
        The type of strategy parameter.


        :param type: The type of this StrategyParameter.
        :type: str
        """
        allowed_values = ["STRING", "BOOLEAN", "NUMBER", "DATETIME"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def description(self):
        """
        **[Required]** Gets the description of this StrategyParameter.
        Text describing the strategy parameter.


        :return: The description of this StrategyParameter.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this StrategyParameter.
        Text describing the strategy parameter.


        :param description: The description of this StrategyParameter.
        :type: str
        """
        self._description = description

    @property
    def is_required(self):
        """
        **[Required]** Gets the is_required of this StrategyParameter.
        Whether this parameter is required.


        :return: The is_required of this StrategyParameter.
        :rtype: bool
        """
        return self._is_required

    @is_required.setter
    def is_required(self, is_required):
        """
        Sets the is_required of this StrategyParameter.
        Whether this parameter is required.


        :param is_required: The is_required of this StrategyParameter.
        :type: bool
        """
        self._is_required = is_required

    @property
    def default_value(self):
        """
        Gets the default_value of this StrategyParameter.
        A default value used for the strategy parameter.


        :return: The default_value of this StrategyParameter.
        :rtype: object
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """
        Sets the default_value of this StrategyParameter.
        A default value used for the strategy parameter.


        :param default_value: The default_value of this StrategyParameter.
        :type: object
        """
        self._default_value = default_value

    @property
    def possible_values(self):
        """
        Gets the possible_values of this StrategyParameter.
        The list of possible values used for these strategy parameters.


        :return: The possible_values of this StrategyParameter.
        :rtype: list[object]
        """
        return self._possible_values

    @possible_values.setter
    def possible_values(self, possible_values):
        """
        Sets the possible_values of this StrategyParameter.
        The list of possible values used for these strategy parameters.


        :param possible_values: The possible_values of this StrategyParameter.
        :type: list[object]
        """
        self._possible_values = possible_values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ParseConnectionDetails(object):
    """
    Parse connections from the connection metadata and Oracle wallet file.
    An error will be returned if more than one of connectionPayload, walletSecretId or walletSecretName are present in the request.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ParseConnectionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param connection_detail:
            The value to assign to the connection_detail property of this ParseConnectionDetails.
        :type connection_detail: oci.data_catalog.models.Connection

        :param connection_payload:
            The value to assign to the connection_payload property of this ParseConnectionDetails.
        :type connection_payload: str

        :param wallet_secret_id:
            The value to assign to the wallet_secret_id property of this ParseConnectionDetails.
        :type wallet_secret_id: str

        :param wallet_secret_name:
            The value to assign to the wallet_secret_name property of this ParseConnectionDetails.
        :type wallet_secret_name: str

        """
        self.swagger_types = {
            'connection_detail': 'Connection',
            'connection_payload': 'str',
            'wallet_secret_id': 'str',
            'wallet_secret_name': 'str'
        }

        self.attribute_map = {
            'connection_detail': 'connectionDetail',
            'connection_payload': 'connectionPayload',
            'wallet_secret_id': 'walletSecretId',
            'wallet_secret_name': 'walletSecretName'
        }

        self._connection_detail = None
        self._connection_payload = None
        self._wallet_secret_id = None
        self._wallet_secret_name = None

    @property
    def connection_detail(self):
        """
        Gets the connection_detail of this ParseConnectionDetails.

        :return: The connection_detail of this ParseConnectionDetails.
        :rtype: oci.data_catalog.models.Connection
        """
        return self._connection_detail

    @connection_detail.setter
    def connection_detail(self, connection_detail):
        """
        Sets the connection_detail of this ParseConnectionDetails.

        :param connection_detail: The connection_detail of this ParseConnectionDetails.
        :type: oci.data_catalog.models.Connection
        """
        self._connection_detail = connection_detail

    @property
    def connection_payload(self):
        """
        Gets the connection_payload of this ParseConnectionDetails.
        The information used to parse the connection from the wallet file payload.


        :return: The connection_payload of this ParseConnectionDetails.
        :rtype: str
        """
        return self._connection_payload

    @connection_payload.setter
    def connection_payload(self, connection_payload):
        """
        Sets the connection_payload of this ParseConnectionDetails.
        The information used to parse the connection from the wallet file payload.


        :param connection_payload: The connection_payload of this ParseConnectionDetails.
        :type: str
        """
        self._connection_payload = connection_payload

    @property
    def wallet_secret_id(self):
        """
        Gets the wallet_secret_id of this ParseConnectionDetails.
        OCID of the OCI Vault secret holding the Oracle wallet to parse.


        :return: The wallet_secret_id of this ParseConnectionDetails.
        :rtype: str
        """
        return self._wallet_secret_id

    @wallet_secret_id.setter
    def wallet_secret_id(self, wallet_secret_id):
        """
        Sets the wallet_secret_id of this ParseConnectionDetails.
        OCID of the OCI Vault secret holding the Oracle wallet to parse.


        :param wallet_secret_id: The wallet_secret_id of this ParseConnectionDetails.
        :type: str
        """
        self._wallet_secret_id = wallet_secret_id

    @property
    def wallet_secret_name(self):
        """
        Gets the wallet_secret_name of this ParseConnectionDetails.
        Name of the OCI Vault secret holding the Oracle wallet to parse.


        :return: The wallet_secret_name of this ParseConnectionDetails.
        :rtype: str
        """
        return self._wallet_secret_name

    @wallet_secret_name.setter
    def wallet_secret_name(self, wallet_secret_name):
        """
        Sets the wallet_secret_name of this ParseConnectionDetails.
        Name of the OCI Vault secret holding the Oracle wallet to parse.


        :param wallet_secret_name: The wallet_secret_name of this ParseConnectionDetails.
        :type: str
        """
        self._wallet_secret_name = wallet_secret_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseConfigurationMetricGroup(object):
    """
    Supported configuration metric groups for database capacity planning service.
    """

    #: A constant which can be used with the metric_name property of a DatabaseConfigurationMetricGroup.
    #: This constant has a value of "DB_EXTERNAL_PROPERTIES"
    METRIC_NAME_DB_EXTERNAL_PROPERTIES = "DB_EXTERNAL_PROPERTIES"

    #: A constant which can be used with the metric_name property of a DatabaseConfigurationMetricGroup.
    #: This constant has a value of "DB_EXTERNAL_INSTANCE"
    METRIC_NAME_DB_EXTERNAL_INSTANCE = "DB_EXTERNAL_INSTANCE"

    #: A constant which can be used with the metric_name property of a DatabaseConfigurationMetricGroup.
    #: This constant has a value of "DB_OS_CONFIG_INSTANCE"
    METRIC_NAME_DB_OS_CONFIG_INSTANCE = "DB_OS_CONFIG_INSTANCE"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseConfigurationMetricGroup object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.opsi.models.DBOSConfigInstance`
        * :class:`~oci.opsi.models.DBExternalInstance`
        * :class:`~oci.opsi.models.DBExternalProperties`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this DatabaseConfigurationMetricGroup.
            Allowed values for this property are: "DB_EXTERNAL_PROPERTIES", "DB_EXTERNAL_INSTANCE", "DB_OS_CONFIG_INSTANCE"
        :type metric_name: str

        :param time_collected:
            The value to assign to the time_collected property of this DatabaseConfigurationMetricGroup.
        :type time_collected: datetime

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_collected': 'datetime'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_collected': 'timeCollected'
        }

        self._metric_name = None
        self._time_collected = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['metricName']

        if type == 'DB_OS_CONFIG_INSTANCE':
            return 'DBOSConfigInstance'

        if type == 'DB_EXTERNAL_INSTANCE':
            return 'DBExternalInstance'

        if type == 'DB_EXTERNAL_PROPERTIES':
            return 'DBExternalProperties'
        else:
            return 'DatabaseConfigurationMetricGroup'

    @property
    def metric_name(self):
        """
        **[Required]** Gets the metric_name of this DatabaseConfigurationMetricGroup.
        Name of the metric group.

        Allowed values for this property are: "DB_EXTERNAL_PROPERTIES", "DB_EXTERNAL_INSTANCE", "DB_OS_CONFIG_INSTANCE"


        :return: The metric_name of this DatabaseConfigurationMetricGroup.
        :rtype: str
        """
        return self._metric_name

    @metric_name.setter
    def metric_name(self, metric_name):
        """
        Sets the metric_name of this DatabaseConfigurationMetricGroup.
        Name of the metric group.


        :param metric_name: The metric_name of this DatabaseConfigurationMetricGroup.
        :type: str
        """
        allowed_values = ["DB_EXTERNAL_PROPERTIES", "DB_EXTERNAL_INSTANCE", "DB_OS_CONFIG_INSTANCE"]
        if not value_allowed_none_or_none_sentinel(metric_name, allowed_values):
            raise ValueError(
                "Invalid value for `metric_name`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._metric_name = metric_name

    @property
    def time_collected(self):
        """
        Gets the time_collected of this DatabaseConfigurationMetricGroup.
        Collection timestamp
        Example: `\"2020-05-06T00:00:00.000Z\"`


        :return: The time_collected of this DatabaseConfigurationMetricGroup.
        :rtype: datetime
        """
        return self._time_collected

    @time_collected.setter
    def time_collected(self, time_collected):
        """
        Sets the time_collected of this DatabaseConfigurationMetricGroup.
        Collection timestamp
        Example: `\"2020-05-06T00:00:00.000Z\"`


        :param time_collected: The time_collected of this DatabaseConfigurationMetricGroup.
        :type: datetime
        """
        self._time_collected = time_collected

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .config_source import ConfigSource
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectStorageConfigSource(ConfigSource):
    """
    Metadata about the Object Storage configuration source.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectStorageConfigSource object with values from keyword arguments. The default value of the :py:attr:`~oci.resource_manager.models.ObjectStorageConfigSource.config_source_type` attribute
        of this class is ``OBJECT_STORAGE_CONFIG_SOURCE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param config_source_type:
            The value to assign to the config_source_type property of this ObjectStorageConfigSource.
            Allowed values for this property are: "ZIP_UPLOAD", "GIT_CONFIG_SOURCE", "COMPARTMENT_CONFIG_SOURCE", "OBJECT_STORAGE_CONFIG_SOURCE"
        :type config_source_type: str

        :param working_directory:
            The value to assign to the working_directory property of this ObjectStorageConfigSource.
        :type working_directory: str

        :param region:
            The value to assign to the region property of this ObjectStorageConfigSource.
        :type region: str

        :param namespace:
            The value to assign to the namespace property of this ObjectStorageConfigSource.
        :type namespace: str

        :param bucket_name:
            The value to assign to the bucket_name property of this ObjectStorageConfigSource.
        :type bucket_name: str

        """
        self.swagger_types = {
            'config_source_type': 'str',
            'working_directory': 'str',
            'region': 'str',
            'namespace': 'str',
            'bucket_name': 'str'
        }

        self.attribute_map = {
            'config_source_type': 'configSourceType',
            'working_directory': 'workingDirectory',
            'region': 'region',
            'namespace': 'namespace',
            'bucket_name': 'bucketName'
        }

        self._config_source_type = None
        self._working_directory = None
        self._region = None
        self._namespace = None
        self._bucket_name = None
        self._config_source_type = 'OBJECT_STORAGE_CONFIG_SOURCE'

    @property
    def region(self):
        """
        **[Required]** Gets the region of this ObjectStorageConfigSource.
        The name of the bucket's region.
        Example: `PHX`


        :return: The region of this ObjectStorageConfigSource.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this ObjectStorageConfigSource.
        The name of the bucket's region.
        Example: `PHX`


        :param region: The region of this ObjectStorageConfigSource.
        :type: str
        """
        self._region = region

    @property
    def namespace(self):
        """
        **[Required]** Gets the namespace of this ObjectStorageConfigSource.
        The Object Storage namespace that contains the bucket.


        :return: The namespace of this ObjectStorageConfigSource.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this ObjectStorageConfigSource.
        The Object Storage namespace that contains the bucket.


        :param namespace: The namespace of this ObjectStorageConfigSource.
        :type: str
        """
        self._namespace = namespace

    @property
    def bucket_name(self):
        """
        **[Required]** Gets the bucket_name of this ObjectStorageConfigSource.
        The name of the bucket that contains the Terraform configuration files.
        Maximum file size (applies to each file in the bucket): 100 MB. (In a bucket, a file is an object.)


        :return: The bucket_name of this ObjectStorageConfigSource.
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """
        Sets the bucket_name of this ObjectStorageConfigSource.
        The name of the bucket that contains the Terraform configuration files.
        Maximum file size (applies to each file in the bucket): 100 MB. (In a bucket, a file is an object.)


        :param bucket_name: The bucket_name of this ObjectStorageConfigSource.
        :type: str
        """
        self._bucket_name = bucket_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BulkEditTagsResourceType(object):
    """
    BulkEditTagsResourceType model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BulkEditTagsResourceType object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param resource_type:
            The value to assign to the resource_type property of this BulkEditTagsResourceType.
        :type resource_type: str

        :param metadata_keys:
            The value to assign to the metadata_keys property of this BulkEditTagsResourceType.
        :type metadata_keys: list[str]

        """
        self.swagger_types = {
            'resource_type': 'str',
            'metadata_keys': 'list[str]'
        }

        self.attribute_map = {
            'resource_type': 'resourceType',
            'metadata_keys': 'metadataKeys'
        }

        self._resource_type = None
        self._metadata_keys = None

    @property
    def resource_type(self):
        """
        **[Required]** Gets the resource_type of this BulkEditTagsResourceType.
        The unique name of the resource type.


        :return: The resource_type of this BulkEditTagsResourceType.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """
        Sets the resource_type of this BulkEditTagsResourceType.
        The unique name of the resource type.


        :param resource_type: The resource_type of this BulkEditTagsResourceType.
        :type: str
        """
        self._resource_type = resource_type

    @property
    def metadata_keys(self):
        """
        Gets the metadata_keys of this BulkEditTagsResourceType.
        The metadata keys required to identify the resource.

        For example, for a bucket, the value of `metadataKeys` will be `\"namespaceName\", \"bucketName\"].
        This information will match the API documentation.
        See [UpdateBucket`__ and
        `DeleteBucket`__.

        __ https://docs.cloud.oracle.com/api/#/en/objectstorage/latest/Bucket/UpdateBucket
        __ https://docs.cloud.oracle.com/api/#/en/objectstorage/latest/Bucket/DeleteBucket


        :return: The metadata_keys of this BulkEditTagsResourceType.
        :rtype: list[str]
        """
        return self._metadata_keys

    @metadata_keys.setter
    def metadata_keys(self, metadata_keys):
        """
        Sets the metadata_keys of this BulkEditTagsResourceType.
        The metadata keys required to identify the resource.

        For example, for a bucket, the value of `metadataKeys` will be `\"namespaceName\", \"bucketName\"].
        This information will match the API documentation.
        See [UpdateBucket`__ and
        `DeleteBucket`__.

        __ https://docs.cloud.oracle.com/api/#/en/objectstorage/latest/Bucket/UpdateBucket
        __ https://docs.cloud.oracle.com/api/#/en/objectstorage/latest/Bucket/DeleteBucket


        :param metadata_keys: The metadata_keys of this BulkEditTagsResourceType.
        :type: list[str]
        """
        self._metadata_keys = metadata_keys

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_deploy_environment_details import CreateDeployEnvironmentDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateOkeClusterDeployEnvironmentDetails(CreateDeployEnvironmentDetails):
    """
    Specifies the Kubernetes cluster environment.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateOkeClusterDeployEnvironmentDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.CreateOkeClusterDeployEnvironmentDetails.deploy_environment_type` attribute
        of this class is ``OKE_CLUSTER`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this CreateOkeClusterDeployEnvironmentDetails.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this CreateOkeClusterDeployEnvironmentDetails.
        :type display_name: str

        :param deploy_environment_type:
            The value to assign to the deploy_environment_type property of this CreateOkeClusterDeployEnvironmentDetails.
        :type deploy_environment_type: str

        :param project_id:
            The value to assign to the project_id property of this CreateOkeClusterDeployEnvironmentDetails.
        :type project_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateOkeClusterDeployEnvironmentDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateOkeClusterDeployEnvironmentDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param cluster_id:
            The value to assign to the cluster_id property of this CreateOkeClusterDeployEnvironmentDetails.
        :type cluster_id: str

        """
        self.swagger_types = {
            'description': 'str',
            'display_name': 'str',
            'deploy_environment_type': 'str',
            'project_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'cluster_id': 'str'
        }

        self.attribute_map = {
            'description': 'description',
            'display_name': 'displayName',
            'deploy_environment_type': 'deployEnvironmentType',
            'project_id': 'projectId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'cluster_id': 'clusterId'
        }

        self._description = None
        self._display_name = None
        self._deploy_environment_type = None
        self._project_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._cluster_id = None
        self._deploy_environment_type = 'OKE_CLUSTER'

    @property
    def cluster_id(self):
        """
        **[Required]** Gets the cluster_id of this CreateOkeClusterDeployEnvironmentDetails.
        The OCID of the Kubernetes cluster.


        :return: The cluster_id of this CreateOkeClusterDeployEnvironmentDetails.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """
        Sets the cluster_id of this CreateOkeClusterDeployEnvironmentDetails.
        The OCID of the Kubernetes cluster.


        :param cluster_id: The cluster_id of this CreateOkeClusterDeployEnvironmentDetails.
        :type: str
        """
        self._cluster_id = cluster_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StatementSummary(object):
    """
    Information derived from parsing a NoSQL SQL statement.
    """

    #: A constant which can be used with the operation property of a StatementSummary.
    #: This constant has a value of "CREATE_TABLE"
    OPERATION_CREATE_TABLE = "CREATE_TABLE"

    #: A constant which can be used with the operation property of a StatementSummary.
    #: This constant has a value of "ALTER_TABLE"
    OPERATION_ALTER_TABLE = "ALTER_TABLE"

    #: A constant which can be used with the operation property of a StatementSummary.
    #: This constant has a value of "DROP_TABLE"
    OPERATION_DROP_TABLE = "DROP_TABLE"

    #: A constant which can be used with the operation property of a StatementSummary.
    #: This constant has a value of "CREATE_INDEX"
    OPERATION_CREATE_INDEX = "CREATE_INDEX"

    #: A constant which can be used with the operation property of a StatementSummary.
    #: This constant has a value of "DROP_INDEX"
    OPERATION_DROP_INDEX = "DROP_INDEX"

    #: A constant which can be used with the operation property of a StatementSummary.
    #: This constant has a value of "SELECT"
    OPERATION_SELECT = "SELECT"

    #: A constant which can be used with the operation property of a StatementSummary.
    #: This constant has a value of "UPDATE"
    OPERATION_UPDATE = "UPDATE"

    #: A constant which can be used with the operation property of a StatementSummary.
    #: This constant has a value of "INSERT"
    OPERATION_INSERT = "INSERT"

    #: A constant which can be used with the operation property of a StatementSummary.
    #: This constant has a value of "DELETE"
    OPERATION_DELETE = "DELETE"

    def __init__(self, **kwargs):
        """
        Initializes a new StatementSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operation:
            The value to assign to the operation property of this StatementSummary.
            Allowed values for this property are: "CREATE_TABLE", "ALTER_TABLE", "DROP_TABLE", "CREATE_INDEX", "DROP_INDEX", "SELECT", "UPDATE", "INSERT", "DELETE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operation: str

        :param table_name:
            The value to assign to the table_name property of this StatementSummary.
        :type table_name: str

        :param index_name:
            The value to assign to the index_name property of this StatementSummary.
        :type index_name: str

        :param is_if_exists:
            The value to assign to the is_if_exists property of this StatementSummary.
        :type is_if_exists: bool

        :param is_if_not_exists:
            The value to assign to the is_if_not_exists property of this StatementSummary.
        :type is_if_not_exists: bool

        :param syntax_error:
            The value to assign to the syntax_error property of this StatementSummary.
        :type syntax_error: str

        """
        self.swagger_types = {
            'operation': 'str',
            'table_name': 'str',
            'index_name': 'str',
            'is_if_exists': 'bool',
            'is_if_not_exists': 'bool',
            'syntax_error': 'str'
        }

        self.attribute_map = {
            'operation': 'operation',
            'table_name': 'tableName',
            'index_name': 'indexName',
            'is_if_exists': 'isIfExists',
            'is_if_not_exists': 'isIfNotExists',
            'syntax_error': 'syntaxError'
        }

        self._operation = None
        self._table_name = None
        self._index_name = None
        self._is_if_exists = None
        self._is_if_not_exists = None
        self._syntax_error = None

    @property
    def operation(self):
        """
        Gets the operation of this StatementSummary.
        The operation represented in the statement, e.g. CREATE_TABLE.

        Allowed values for this property are: "CREATE_TABLE", "ALTER_TABLE", "DROP_TABLE", "CREATE_INDEX", "DROP_INDEX", "SELECT", "UPDATE", "INSERT", "DELETE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operation of this StatementSummary.
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """
        Sets the operation of this StatementSummary.
        The operation represented in the statement, e.g. CREATE_TABLE.


        :param operation: The operation of this StatementSummary.
        :type: str
        """
        allowed_values = ["CREATE_TABLE", "ALTER_TABLE", "DROP_TABLE", "CREATE_INDEX", "DROP_INDEX", "SELECT", "UPDATE", "INSERT", "DELETE"]
        if not value_allowed_none_or_none_sentinel(operation, allowed_values):
            operation = 'UNKNOWN_ENUM_VALUE'
        self._operation = operation

    @property
    def table_name(self):
        """
        Gets the table_name of this StatementSummary.
        The table name from the SQL statement.


        :return: The table_name of this StatementSummary.
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """
        Sets the table_name of this StatementSummary.
        The table name from the SQL statement.


        :param table_name: The table_name of this StatementSummary.
        :type: str
        """
        self._table_name = table_name

    @property
    def index_name(self):
        """
        Gets the index_name of this StatementSummary.
        The index name from the SQL statement, if present.


        :return: The index_name of this StatementSummary.
        :rtype: str
        """
        return self._index_name

    @index_name.setter
    def index_name(self, index_name):
        """
        Sets the index_name of this StatementSummary.
        The index name from the SQL statement, if present.


        :param index_name: The index_name of this StatementSummary.
        :type: str
        """
        self._index_name = index_name

    @property
    def is_if_exists(self):
        """
        Gets the is_if_exists of this StatementSummary.
        True if the statement includes \"IF EXISTS.\"


        :return: The is_if_exists of this StatementSummary.
        :rtype: bool
        """
        return self._is_if_exists

    @is_if_exists.setter
    def is_if_exists(self, is_if_exists):
        """
        Sets the is_if_exists of this StatementSummary.
        True if the statement includes \"IF EXISTS.\"


        :param is_if_exists: The is_if_exists of this StatementSummary.
        :type: bool
        """
        self._is_if_exists = is_if_exists

    @property
    def is_if_not_exists(self):
        """
        Gets the is_if_not_exists of this StatementSummary.
        True if the statement includes \"IF NOT EXISTS.\"


        :return: The is_if_not_exists of this StatementSummary.
        :rtype: bool
        """
        return self._is_if_not_exists

    @is_if_not_exists.setter
    def is_if_not_exists(self, is_if_not_exists):
        """
        Sets the is_if_not_exists of this StatementSummary.
        True if the statement includes \"IF NOT EXISTS.\"


        :param is_if_not_exists: The is_if_not_exists of this StatementSummary.
        :type: bool
        """
        self._is_if_not_exists = is_if_not_exists

    @property
    def syntax_error(self):
        """
        Gets the syntax_error of this StatementSummary.
        If present, indicates a syntax error in the statement.


        :return: The syntax_error of this StatementSummary.
        :rtype: str
        """
        return self._syntax_error

    @syntax_error.setter
    def syntax_error(self, syntax_error):
        """
        Sets the syntax_error of this StatementSummary.
        If present, indicates a syntax error in the statement.


        :param syntax_error: The syntax_error of this StatementSummary.
        :type: str
        """
        self._syntax_error = syntax_error

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateRoverClusterDetails(object):
    """
    The information required to create a RoverCluster.
    """

    #: A constant which can be used with the enclosure_type property of a CreateRoverClusterDetails.
    #: This constant has a value of "RUGGADIZED"
    ENCLOSURE_TYPE_RUGGADIZED = "RUGGADIZED"

    #: A constant which can be used with the enclosure_type property of a CreateRoverClusterDetails.
    #: This constant has a value of "NON_RUGGADIZED"
    ENCLOSURE_TYPE_NON_RUGGADIZED = "NON_RUGGADIZED"

    #: A constant which can be used with the shipping_preference property of a CreateRoverClusterDetails.
    #: This constant has a value of "ORACLE_SHIPPED"
    SHIPPING_PREFERENCE_ORACLE_SHIPPED = "ORACLE_SHIPPED"

    #: A constant which can be used with the shipping_preference property of a CreateRoverClusterDetails.
    #: This constant has a value of "CUSTOMER_PICKUP"
    SHIPPING_PREFERENCE_CUSTOMER_PICKUP = "CUSTOMER_PICKUP"

    #: A constant which can be used with the lifecycle_state property of a CreateRoverClusterDetails.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a CreateRoverClusterDetails.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a CreateRoverClusterDetails.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a CreateRoverClusterDetails.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a CreateRoverClusterDetails.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a CreateRoverClusterDetails.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateRoverClusterDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateRoverClusterDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateRoverClusterDetails.
        :type compartment_id: str

        :param cluster_size:
            The value to assign to the cluster_size property of this CreateRoverClusterDetails.
        :type cluster_size: int

        :param customer_shipping_address:
            The value to assign to the customer_shipping_address property of this CreateRoverClusterDetails.
        :type customer_shipping_address: oci.rover.models.ShippingAddress

        :param cluster_workloads:
            The value to assign to the cluster_workloads property of this CreateRoverClusterDetails.
        :type cluster_workloads: list[oci.rover.models.RoverWorkload]

        :param super_user_password:
            The value to assign to the super_user_password property of this CreateRoverClusterDetails.
        :type super_user_password: str

        :param enclosure_type:
            The value to assign to the enclosure_type property of this CreateRoverClusterDetails.
            Allowed values for this property are: "RUGGADIZED", "NON_RUGGADIZED"
        :type enclosure_type: str

        :param unlock_passphrase:
            The value to assign to the unlock_passphrase property of this CreateRoverClusterDetails.
        :type unlock_passphrase: str

        :param point_of_contact:
            The value to assign to the point_of_contact property of this CreateRoverClusterDetails.
        :type point_of_contact: str

        :param point_of_contact_phone_number:
            The value to assign to the point_of_contact_phone_number property of this CreateRoverClusterDetails.
        :type point_of_contact_phone_number: str

        :param shipping_preference:
            The value to assign to the shipping_preference property of this CreateRoverClusterDetails.
            Allowed values for this property are: "ORACLE_SHIPPED", "CUSTOMER_PICKUP"
        :type shipping_preference: str

        :param shipping_vendor:
            The value to assign to the shipping_vendor property of this CreateRoverClusterDetails.
        :type shipping_vendor: str

        :param time_pickup_expected:
            The value to assign to the time_pickup_expected property of this CreateRoverClusterDetails.
        :type time_pickup_expected: datetime

        :param oracle_shipping_tracking_url:
            The value to assign to the oracle_shipping_tracking_url property of this CreateRoverClusterDetails.
        :type oracle_shipping_tracking_url: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this CreateRoverClusterDetails.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"
        :type lifecycle_state: str

        :param lifecycle_state_details:
            The value to assign to the lifecycle_state_details property of this CreateRoverClusterDetails.
        :type lifecycle_state_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateRoverClusterDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateRoverClusterDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this CreateRoverClusterDetails.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'compartment_id': 'str',
            'cluster_size': 'int',
            'customer_shipping_address': 'ShippingAddress',
            'cluster_workloads': 'list[RoverWorkload]',
            'super_user_password': 'str',
            'enclosure_type': 'str',
            'unlock_passphrase': 'str',
            'point_of_contact': 'str',
            'point_of_contact_phone_number': 'str',
            'shipping_preference': 'str',
            'shipping_vendor': 'str',
            'time_pickup_expected': 'datetime',
            'oracle_shipping_tracking_url': 'str',
            'lifecycle_state': 'str',
            'lifecycle_state_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'cluster_size': 'clusterSize',
            'customer_shipping_address': 'customerShippingAddress',
            'cluster_workloads': 'clusterWorkloads',
            'super_user_password': 'superUserPassword',
            'enclosure_type': 'enclosureType',
            'unlock_passphrase': 'unlockPassphrase',
            'point_of_contact': 'pointOfContact',
            'point_of_contact_phone_number': 'pointOfContactPhoneNumber',
            'shipping_preference': 'shippingPreference',
            'shipping_vendor': 'shippingVendor',
            'time_pickup_expected': 'timePickupExpected',
            'oracle_shipping_tracking_url': 'oracleShippingTrackingUrl',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_state_details': 'lifecycleStateDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._display_name = None
        self._compartment_id = None
        self._cluster_size = None
        self._customer_shipping_address = None
        self._cluster_workloads = None
        self._super_user_password = None
        self._enclosure_type = None
        self._unlock_passphrase = None
        self._point_of_contact = None
        self._point_of_contact_phone_number = None
        self._shipping_preference = None
        self._shipping_vendor = None
        self._time_pickup_expected = None
        self._oracle_shipping_tracking_url = None
        self._lifecycle_state = None
        self._lifecycle_state_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateRoverClusterDetails.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :return: The display_name of this CreateRoverClusterDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateRoverClusterDetails.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :param display_name: The display_name of this CreateRoverClusterDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateRoverClusterDetails.
        The OCID of the compartment containing the RoverCluster.


        :return: The compartment_id of this CreateRoverClusterDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateRoverClusterDetails.
        The OCID of the compartment containing the RoverCluster.


        :param compartment_id: The compartment_id of this CreateRoverClusterDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def cluster_size(self):
        """
        **[Required]** Gets the cluster_size of this CreateRoverClusterDetails.
        Number of nodes desired in the cluster, between 5 and 15.


        :return: The cluster_size of this CreateRoverClusterDetails.
        :rtype: int
        """
        return self._cluster_size

    @cluster_size.setter
    def cluster_size(self, cluster_size):
        """
        Sets the cluster_size of this CreateRoverClusterDetails.
        Number of nodes desired in the cluster, between 5 and 15.


        :param cluster_size: The cluster_size of this CreateRoverClusterDetails.
        :type: int
        """
        self._cluster_size = cluster_size

    @property
    def customer_shipping_address(self):
        """
        Gets the customer_shipping_address of this CreateRoverClusterDetails.

        :return: The customer_shipping_address of this CreateRoverClusterDetails.
        :rtype: oci.rover.models.ShippingAddress
        """
        return self._customer_shipping_address

    @customer_shipping_address.setter
    def customer_shipping_address(self, customer_shipping_address):
        """
        Sets the customer_shipping_address of this CreateRoverClusterDetails.

        :param customer_shipping_address: The customer_shipping_address of this CreateRoverClusterDetails.
        :type: oci.rover.models.ShippingAddress
        """
        self._customer_shipping_address = customer_shipping_address

    @property
    def cluster_workloads(self):
        """
        Gets the cluster_workloads of this CreateRoverClusterDetails.
        List of existing workloads that should be provisioned on the nodes.


        :return: The cluster_workloads of this CreateRoverClusterDetails.
        :rtype: list[oci.rover.models.RoverWorkload]
        """
        return self._cluster_workloads

    @cluster_workloads.setter
    def cluster_workloads(self, cluster_workloads):
        """
        Sets the cluster_workloads of this CreateRoverClusterDetails.
        List of existing workloads that should be provisioned on the nodes.


        :param cluster_workloads: The cluster_workloads of this CreateRoverClusterDetails.
        :type: list[oci.rover.models.RoverWorkload]
        """
        self._cluster_workloads = cluster_workloads

    @property
    def super_user_password(self):
        """
        Gets the super_user_password of this CreateRoverClusterDetails.
        Root password for the rover cluster.


        :return: The super_user_password of this CreateRoverClusterDetails.
        :rtype: str
        """
        return self._super_user_password

    @super_user_password.setter
    def super_user_password(self, super_user_password):
        """
        Sets the super_user_password of this CreateRoverClusterDetails.
        Root password for the rover cluster.


        :param super_user_password: The super_user_password of this CreateRoverClusterDetails.
        :type: str
        """
        self._super_user_password = super_user_password

    @property
    def enclosure_type(self):
        """
        Gets the enclosure_type of this CreateRoverClusterDetails.
        The type of enclosure rover nodes in this cluster are shipped in.

        Allowed values for this property are: "RUGGADIZED", "NON_RUGGADIZED"


        :return: The enclosure_type of this CreateRoverClusterDetails.
        :rtype: str
        """
        return self._enclosure_type

    @enclosure_type.setter
    def enclosure_type(self, enclosure_type):
        """
        Sets the enclosure_type of this CreateRoverClusterDetails.
        The type of enclosure rover nodes in this cluster are shipped in.


        :param enclosure_type: The enclosure_type of this CreateRoverClusterDetails.
        :type: str
        """
        allowed_values = ["RUGGADIZED", "NON_RUGGADIZED"]
        if not value_allowed_none_or_none_sentinel(enclosure_type, allowed_values):
            raise ValueError(
                "Invalid value for `enclosure_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._enclosure_type = enclosure_type

    @property
    def unlock_passphrase(self):
        """
        Gets the unlock_passphrase of this CreateRoverClusterDetails.
        Password to unlock the rover cluster.


        :return: The unlock_passphrase of this CreateRoverClusterDetails.
        :rtype: str
        """
        return self._unlock_passphrase

    @unlock_passphrase.setter
    def unlock_passphrase(self, unlock_passphrase):
        """
        Sets the unlock_passphrase of this CreateRoverClusterDetails.
        Password to unlock the rover cluster.


        :param unlock_passphrase: The unlock_passphrase of this CreateRoverClusterDetails.
        :type: str
        """
        self._unlock_passphrase = unlock_passphrase

    @property
    def point_of_contact(self):
        """
        Gets the point_of_contact of this CreateRoverClusterDetails.
        Name of point of contact for this order if customer is picking up.


        :return: The point_of_contact of this CreateRoverClusterDetails.
        :rtype: str
        """
        return self._point_of_contact

    @point_of_contact.setter
    def point_of_contact(self, point_of_contact):
        """
        Sets the point_of_contact of this CreateRoverClusterDetails.
        Name of point of contact for this order if customer is picking up.


        :param point_of_contact: The point_of_contact of this CreateRoverClusterDetails.
        :type: str
        """
        self._point_of_contact = point_of_contact

    @property
    def point_of_contact_phone_number(self):
        """
        Gets the point_of_contact_phone_number of this CreateRoverClusterDetails.
        Phone number of point of contact for this order if customer is picking up.


        :return: The point_of_contact_phone_number of this CreateRoverClusterDetails.
        :rtype: str
        """
        return self._point_of_contact_phone_number

    @point_of_contact_phone_number.setter
    def point_of_contact_phone_number(self, point_of_contact_phone_number):
        """
        Sets the point_of_contact_phone_number of this CreateRoverClusterDetails.
        Phone number of point of contact for this order if customer is picking up.


        :param point_of_contact_phone_number: The point_of_contact_phone_number of this CreateRoverClusterDetails.
        :type: str
        """
        self._point_of_contact_phone_number = point_of_contact_phone_number

    @property
    def shipping_preference(self):
        """
        Gets the shipping_preference of this CreateRoverClusterDetails.
        Preference for device delivery.

        Allowed values for this property are: "ORACLE_SHIPPED", "CUSTOMER_PICKUP"


        :return: The shipping_preference of this CreateRoverClusterDetails.
        :rtype: str
        """
        return self._shipping_preference

    @shipping_preference.setter
    def shipping_preference(self, shipping_preference):
        """
        Sets the shipping_preference of this CreateRoverClusterDetails.
        Preference for device delivery.


        :param shipping_preference: The shipping_preference of this CreateRoverClusterDetails.
        :type: str
        """
        allowed_values = ["ORACLE_SHIPPED", "CUSTOMER_PICKUP"]
        if not value_allowed_none_or_none_sentinel(shipping_preference, allowed_values):
            raise ValueError(
                "Invalid value for `shipping_preference`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._shipping_preference = shipping_preference

    @property
    def shipping_vendor(self):
        """
        Gets the shipping_vendor of this CreateRoverClusterDetails.
        Shipping vendor of choice for orace to customer shipping.


        :return: The shipping_vendor of this CreateRoverClusterDetails.
        :rtype: str
        """
        return self._shipping_vendor

    @shipping_vendor.setter
    def shipping_vendor(self, shipping_vendor):
        """
        Sets the shipping_vendor of this CreateRoverClusterDetails.
        Shipping vendor of choice for orace to customer shipping.


        :param shipping_vendor: The shipping_vendor of this CreateRoverClusterDetails.
        :type: str
        """
        self._shipping_vendor = shipping_vendor

    @property
    def time_pickup_expected(self):
        """
        Gets the time_pickup_expected of this CreateRoverClusterDetails.
        Expected date when customer wants to pickup the cluster if they chose customer pickup.


        :return: The time_pickup_expected of this CreateRoverClusterDetails.
        :rtype: datetime
        """
        return self._time_pickup_expected

    @time_pickup_expected.setter
    def time_pickup_expected(self, time_pickup_expected):
        """
        Sets the time_pickup_expected of this CreateRoverClusterDetails.
        Expected date when customer wants to pickup the cluster if they chose customer pickup.


        :param time_pickup_expected: The time_pickup_expected of this CreateRoverClusterDetails.
        :type: datetime
        """
        self._time_pickup_expected = time_pickup_expected

    @property
    def oracle_shipping_tracking_url(self):
        """
        Gets the oracle_shipping_tracking_url of this CreateRoverClusterDetails.
        Tracking Url for the shipped Rover Cluster.


        :return: The oracle_shipping_tracking_url of this CreateRoverClusterDetails.
        :rtype: str
        """
        return self._oracle_shipping_tracking_url

    @oracle_shipping_tracking_url.setter
    def oracle_shipping_tracking_url(self, oracle_shipping_tracking_url):
        """
        Sets the oracle_shipping_tracking_url of this CreateRoverClusterDetails.
        Tracking Url for the shipped Rover Cluster.


        :param oracle_shipping_tracking_url: The oracle_shipping_tracking_url of this CreateRoverClusterDetails.
        :type: str
        """
        self._oracle_shipping_tracking_url = oracle_shipping_tracking_url

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this CreateRoverClusterDetails.
        The current state of the RoverCluster.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"


        :return: The lifecycle_state of this CreateRoverClusterDetails.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this CreateRoverClusterDetails.
        The current state of the RoverCluster.


        :param lifecycle_state: The lifecycle_state of this CreateRoverClusterDetails.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            raise ValueError(
                "Invalid value for `lifecycle_state`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_state_details(self):
        """
        Gets the lifecycle_state_details of this CreateRoverClusterDetails.
        A property that can contain details on the lifecycle.


        :return: The lifecycle_state_details of this CreateRoverClusterDetails.
        :rtype: str
        """
        return self._lifecycle_state_details

    @lifecycle_state_details.setter
    def lifecycle_state_details(self, lifecycle_state_details):
        """
        Sets the lifecycle_state_details of this CreateRoverClusterDetails.
        A property that can contain details on the lifecycle.


        :param lifecycle_state_details: The lifecycle_state_details of this CreateRoverClusterDetails.
        :type: str
        """
        self._lifecycle_state_details = lifecycle_state_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateRoverClusterDetails.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateRoverClusterDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateRoverClusterDetails.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateRoverClusterDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateRoverClusterDetails.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateRoverClusterDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateRoverClusterDetails.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateRoverClusterDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this CreateRoverClusterDetails.
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The system_tags of this CreateRoverClusterDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this CreateRoverClusterDetails.
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param system_tags: The system_tags of this CreateRoverClusterDetails.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
